==> qmmp-debug-2.2.1-1-x86_64.pkg.tar.zst: usr/src/debug/qmmp/qmmp-2.2.1/src/plugins/General/converter/converter_autogen/EWIEGA46WW/qrc_presets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // presets.conf
  0x0,0x0,0x2,0x6f,
  0x6e,
  0x61,0x6d,0x65,0x3d,0x4f,0x67,0x67,0x20,0x56,0x6f,0x72,0x62,0x69,0x73,0x20,0x28,
  0x6f,0x67,0x67,0x65,0x6e,0x63,0x29,0xa,0x65,0x78,0x74,0x3d,0x6f,0x67,0x67,0xa,
  0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x6f,0x67,0x67,0x65,0x6e,0x63,0x20,0x2d,
  0x71,0x20,0x35,0x20,0x2d,0x6f,0x20,0x25,0x6f,0x20,0x2d,0xa,0x75,0x73,0x65,0x5f,
  0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,
  0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,0x6d,0x65,0x3d,0x4d,0x50,0x45,0x47,0x20,
  0x6c,0x61,0x79,0x65,0x72,0x20,0x33,0x2c,0x20,0x33,0x32,0x30,0x20,0x6b,0x62,0x70,
  0x73,0x20,0x28,0x6c,0x61,0x6d,0x65,0x29,0xa,0x65,0x78,0x74,0x3d,0x6d,0x70,0x33,
  0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x6c,0x61,0x6d,0x65,0x20,0x2d,0x2d,
  0x70,0x72,0x65,0x73,0x65,0x74,0x20,0x63,0x62,0x72,0x20,0x33,0x32,0x30,0x20,0x2d,
  0x20,0x25,0x6f,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,
  0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,
  0x6d,0x65,0x3d,0x4d,0x50,0x45,0x47,0x20,0x6c,0x61,0x79,0x65,0x72,0x20,0x33,0x2c,
  0x20,0x31,0x39,0x32,0x20,0x6b,0x62,0x70,0x73,0x20,0x28,0x6c,0x61,0x6d,0x65,0x29,
  0xa,0x65,0x78,0x74,0x3d,0x6d,0x70,0x33,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,
  0x3d,0x6c,0x61,0x6d,0x65,0x20,0x2d,0x56,0x32,0x20,0x2d,0x20,0x25,0x6f,0xa,0x75,
  0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,
  0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,0x6d,0x65,0x3d,0x4d,0x50,
  0x45,0x47,0x20,0x6c,0x61,0x79,0x65,0x72,0x20,0x33,0x2c,0x20,0x31,0x32,0x38,0x20,
  0x6b,0x62,0x70,0x73,0x20,0x28,0x6c,0x61,0x6d,0x65,0x29,0xa,0x65,0x78,0x74,0x3d,
  0x6d,0x70,0x33,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x6c,0x61,0x6d,0x65,
  0x20,0x2d,0x2d,0x70,0x72,0x65,0x73,0x65,0x74,0x20,0x63,0x62,0x72,0x20,0x31,0x32,
  0x38,0x20,0x2d,0x20,0x25,0x6f,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,
  0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,
  0xa,0x6e,0x61,0x6d,0x65,0x3d,0x4f,0x67,0x67,0x20,0x4f,0x70,0x75,0x73,0xa,0x65,
  0x78,0x74,0x3d,0x6f,0x70,0x75,0x73,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,
  0x6f,0x70,0x75,0x73,0x65,0x6e,0x63,0x20,0x2d,0x20,0x25,0x6f,0xa,0x75,0x73,0x65,
  0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,0x67,0x73,
  0x3d,0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,0x6d,0x65,0x3d,0x57,0x61,0x76,0x50,
  0x61,0x63,0x6b,0xa,0x65,0x78,0x74,0x3d,0x77,0x76,0xa,0x63,0x6f,0x6d,0x6d,0x61,
  0x6e,0x64,0x3d,0x77,0x61,0x76,0x70,0x61,0x63,0x6b,0x20,0x2d,0x69,0x20,0x2d,0x20,
  0x2d,0x6f,0x20,0x25,0x6f,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,
  0x66,0x61,0x6c,0x73,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,
  0xa,0x6e,0x61,0x6d,0x65,0x3d,0x46,0x4c,0x41,0x43,0xa,0x65,0x78,0x74,0x3d,0x66,
  0x6c,0x61,0x63,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x66,0x6c,0x61,0x63,
  0x20,0x2d,0x6f,0x20,0x25,0x6f,0x20,0x2d,0x35,0x20,0x2d,0x2d,0x69,0x67,0x6e,0x6f,
  0x72,0x65,0x2d,0x63,0x68,0x75,0x6e,0x6b,0x2d,0x73,0x69,0x7a,0x65,0x73,0x20,0x2d,
  0x66,0x20,0x2d,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,
  0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // converter
  0x0,0x9,
  0x5,0xcc,0x4e,0x2,
  0x0,0x63,
  0x0,0x6f,0x0,0x6e,0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x65,0x0,0x72,
    // presets.conf
  0x0,0xc,
  0x5,0xd5,0x39,0xc6,
  0x0,0x70,
  0x0,0x72,0x0,0x65,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,0x0,0x2e,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x8,0xca,0xf1,0x10,
  // :/converter
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x8,0xca,0xf1,0x10,
  // :/converter/presets.conf
  0x0,0x0,0x0,0x18,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x8,0xca,0xf1,0x10,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_presets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_presets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_presets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_presets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_presets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_presets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qmmp-debug-2.2.1-1.1-x86_64.pkg.tar.zst: usr/src/debug/qmmp/qmmp-2.2.1/src/plugins/General/converter/converter_autogen/EWIEGA46WW/qrc_presets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // presets.conf
  0x0,0x0,0x2,0x6f,
  0x6e,
  0x61,0x6d,0x65,0x3d,0x4f,0x67,0x67,0x20,0x56,0x6f,0x72,0x62,0x69,0x73,0x20,0x28,
  0x6f,0x67,0x67,0x65,0x6e,0x63,0x29,0xa,0x65,0x78,0x74,0x3d,0x6f,0x67,0x67,0xa,
  0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x6f,0x67,0x67,0x65,0x6e,0x63,0x20,0x2d,
  0x71,0x20,0x35,0x20,0x2d,0x6f,0x20,0x25,0x6f,0x20,0x2d,0xa,0x75,0x73,0x65,0x5f,
  0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,
  0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,0x6d,0x65,0x3d,0x4d,0x50,0x45,0x47,0x20,
  0x6c,0x61,0x79,0x65,0x72,0x20,0x33,0x2c,0x20,0x33,0x32,0x30,0x20,0x6b,0x62,0x70,
  0x73,0x20,0x28,0x6c,0x61,0x6d,0x65,0x29,0xa,0x65,0x78,0x74,0x3d,0x6d,0x70,0x33,
  0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x6c,0x61,0x6d,0x65,0x20,0x2d,0x2d,
  0x70,0x72,0x65,0x73,0x65,0x74,0x20,0x63,0x62,0x72,0x20,0x33,0x32,0x30,0x20,0x2d,
  0x20,0x25,0x6f,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,
  0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,
  0x6d,0x65,0x3d,0x4d,0x50,0x45,0x47,0x20,0x6c,0x61,0x79,0x65,0x72,0x20,0x33,0x2c,
  0x20,0x31,0x39,0x32,0x20,0x6b,0x62,0x70,0x73,0x20,0x28,0x6c,0x61,0x6d,0x65,0x29,
  0xa,0x65,0x78,0x74,0x3d,0x6d,0x70,0x33,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,
  0x3d,0x6c,0x61,0x6d,0x65,0x20,0x2d,0x56,0x32,0x20,0x2d,0x20,0x25,0x6f,0xa,0x75,
  0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,
  0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,0x6d,0x65,0x3d,0x4d,0x50,
  0x45,0x47,0x20,0x6c,0x61,0x79,0x65,0x72,0x20,0x33,0x2c,0x20,0x31,0x32,0x38,0x20,
  0x6b,0x62,0x70,0x73,0x20,0x28,0x6c,0x61,0x6d,0x65,0x29,0xa,0x65,0x78,0x74,0x3d,
  0x6d,0x70,0x33,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x6c,0x61,0x6d,0x65,
  0x20,0x2d,0x2d,0x70,0x72,0x65,0x73,0x65,0x74,0x20,0x63,0x62,0x72,0x20,0x31,0x32,
  0x38,0x20,0x2d,0x20,0x25,0x6f,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,
  0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,
  0xa,0x6e,0x61,0x6d,0x65,0x3d,0x4f,0x67,0x67,0x20,0x4f,0x70,0x75,0x73,0xa,0x65,
  0x78,0x74,0x3d,0x6f,0x70,0x75,0x73,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,
  0x6f,0x70,0x75,0x73,0x65,0x6e,0x63,0x20,0x2d,0x20,0x25,0x6f,0xa,0x75,0x73,0x65,
  0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,0x75,0x65,0xa,0x74,0x61,0x67,0x73,
  0x3d,0x74,0x72,0x75,0x65,0xa,0xa,0x6e,0x61,0x6d,0x65,0x3d,0x57,0x61,0x76,0x50,
  0x61,0x63,0x6b,0xa,0x65,0x78,0x74,0x3d,0x77,0x76,0xa,0x63,0x6f,0x6d,0x6d,0x61,
  0x6e,0x64,0x3d,0x77,0x61,0x76,0x70,0x61,0x63,0x6b,0x20,0x2d,0x69,0x20,0x2d,0x20,
  0x2d,0x6f,0x20,0x25,0x6f,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,
  0x66,0x61,0x6c,0x73,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,
  0xa,0x6e,0x61,0x6d,0x65,0x3d,0x46,0x4c,0x41,0x43,0xa,0x65,0x78,0x74,0x3d,0x66,
  0x6c,0x61,0x63,0xa,0x63,0x6f,0x6d,0x6d,0x61,0x6e,0x64,0x3d,0x66,0x6c,0x61,0x63,
  0x20,0x2d,0x6f,0x20,0x25,0x6f,0x20,0x2d,0x35,0x20,0x2d,0x2d,0x69,0x67,0x6e,0x6f,
  0x72,0x65,0x2d,0x63,0x68,0x75,0x6e,0x6b,0x2d,0x73,0x69,0x7a,0x65,0x73,0x20,0x2d,
  0x66,0x20,0x2d,0xa,0x75,0x73,0x65,0x5f,0x31,0x36,0x62,0x69,0x74,0x3d,0x74,0x72,
  0x75,0x65,0xa,0x74,0x61,0x67,0x73,0x3d,0x74,0x72,0x75,0x65,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // converter
  0x0,0x9,
  0x5,0xcc,0x4e,0x2,
  0x0,0x63,
  0x0,0x6f,0x0,0x6e,0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x65,0x0,0x72,
    // presets.conf
  0x0,0xc,
  0x5,0xd5,0x39,0xc6,
  0x0,0x70,
  0x0,0x72,0x0,0x65,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,0x0,0x2e,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x9,0xf9,0xc8,0x68,
  // :/converter
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x9,0xf9,0xc8,0x68,
  // :/converter/presets.conf
  0x0,0x0,0x0,0x18,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x9,0xf9,0xc8,0x68,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_presets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_presets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_presets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_presets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_presets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_presets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
